==> ejb-full-container-6.2.2-sources.jar: org/glassfish/ejb/mdb/MessageBeanContainerFactory.java <==
/*
 * Copyright (c) 1997, 2018 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package org.glassfish.ejb.mdb;

import com.sun.ejb.containers.BaseContainerFactory;
import jakarta.inject.Singleton;
import org.glassfish.api.deployment.DeploymentContext;
import com.sun.enterprise.security.SecurityManager;
import org.jvnet.hk2.annotations.Service;
import com.sun.ejb.Container;
import com.sun.ejb.ContainerFactory;
import org.glassfish.ejb.deployment.descriptor.EjbDescriptor;

@Service(name = "MessageBeanContainerFactory")
@Singleton
public final class MessageBeanContainerFactory extends BaseContainerFactory implements ContainerFactory {

    @Override
    public Container createContainer(EjbDescriptor ejbDescriptor, ClassLoader loader, DeploymentContext deployContext)
        throws Exception {
        SecurityManager sm = getSecurityManager(ejbDescriptor);
        MessageBeanContainer mdbContainer = new MessageBeanContainer(ejbDescriptor, loader, sm);
        return mdbContainer;
    }
}

==> ejb-full-container-7.0.23-sources.jar: org/glassfish/ejb/mdb/MessageBeanContainerFactory.java <==
/*
 * Copyright (c) 2022, 2022 Contributors to the Eclipse Foundation.
 * Copyright (c) 1997, 2018 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package org.glassfish.ejb.mdb;

import com.sun.ejb.Container;
import com.sun.ejb.ContainerFactory;
import com.sun.ejb.containers.BaseContainerFactory;

import jakarta.inject.Singleton;

import org.glassfish.api.deployment.DeploymentContext;
import org.glassfish.ejb.deployment.descriptor.EjbDescriptor;
import org.jvnet.hk2.annotations.Service;

@Service(name = "MessageBeanContainerFactory")
@Singleton
public final class MessageBeanContainerFactory extends BaseContainerFactory implements ContainerFactory {

    @Override
    public Container createContainer(EjbDescriptor ejbDescriptor, ClassLoader loader, DeploymentContext deployContext) throws Exception {
        return new MessageBeanContainer(ejbDescriptor, loader, getSecurityManager(ejbDescriptor));
    }
}
